%define _name   debugger
%define _exe    edb

Name:           edb-debugger
Summary:        A free OllyDbg like debugger
Version:        1.5.0
Release:        %mkrel 2
Group:          Development/Other
License:        GPLv2
URL:            https://codef00.com/projects
Source0:        https://github.com/eteran/edb-debugger/releases/download/%{version}/%{name}-%{version}.tgz
Patch0:         0001-more-cmake-modernization-where-it-is-obvious.patch

ExclusiveArch: %{ix86} x86_64

BuildRequires: pkgconfig(Qt5Concurrent)
BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Gui)
BuildRequires: pkgconfig(Qt5Help)
BuildRequires: pkgconfig(Qt5Network)
BuildRequires: pkgconfig(Qt5Svg)
BuildRequires: pkgconfig(Qt5Widgets)
BuildRequires: pkgconfig(Qt5Xml)
BuildRequires: pkgconfig(Qt5XmlPatterns)
BuildRequires: pkgconfig(capstone)
BuildRequires: pkgconfig(libgvc)
BuildRequires: cmake(double-conversion)
BuildRequires: boost-devel >= 1.35
BuildRequires: cmake
BuildRequires: imagemagick

%description
One of the main goals of this debugger is modularity.
The interface is written in Qt5 and is therefore source portable
to many platforms. The debugger core is a plugin and the platform
specific code is isolated to just a few files, porting to a new OS
would require porting these few files and implementing a plugin
which implements the DebuggerCoreInterface interface. Also,
because the plugins are based on the QPlugin API, and do their work
through the DebuggerCoreInterface object, they are almost always
portable with just a simple recompile.
The disassembly engine is my edisassm project. I feel that this
disassembler is mature and works well. It is worth noting that the
current version of edb has temporarily dropped AT&T syntax support.
Once this is implemented in edisassm, it will return.

%prep
%autosetup -p1 -n %{name}

%build
%define _disable_ld_no_undefined 1
%cmake_qt5 -DBUILD_SHARED_LIBS=OFF \
           -DDEFAULT_PLUGIN_DIR=%{_libdir}/%{_exe}
%cmake_build

%install
%cmake_install

desktop-file-install --vendor="" \
		     --dir %{buildroot}%{_datadir}/applications \
                     --remove-category="Qt" \
		     %{_exe}.desktop

#install appdata file
mkdir -p %{buildroot}%{_metainfodir}
install -m 644 %{_exe}.appdata.xml %{buildroot}%{_metainfodir}/%{_exe}.appdata.xml

%files
%doc CHANGELOG README.md
%license COPYING
%{_bindir}/%{_exe}
%{_libdir}/%{_exe}/
%{_datadir}/applications/%{_exe}.desktop
%{_datadir}/pixmaps/%{_exe}.png
%{_metainfodir}/%{_exe}.appdata.xml
%{_mandir}/man1/%{_exe}.1.*


%changelog
* Sat Jul 12 2025 daviddavid <daviddavid> 1.5.0-2.mga10
+ Revision: 2253599
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Mon Nov 11 2024 daviddavid <daviddavid> 1.5.0-1.mga10
+ Revision: 2114248
- new version: 1.5.0

* Wed Mar 06 2024 daviddavid <daviddavid> 1.4.0-2.mga10
+ Revision: 2047815
- bundled gdtoa-desktop should be linked as static libs so disable BUILD_SHARED_LIBS

* Tue Feb 27 2024 daviddavid <daviddavid> 1.4.0-1.mga10
+ Revision: 2044566
- new version: 1.4.0
+ tv <tv>
- Rebuild for capstone-5

* Sat Apr 23 2022 papoteur <papoteur> 1.3.0-2.mga9
+ Revision: 1852832
- fix build with GCC 12
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Mar 05 2021 daviddavid <daviddavid> 1.3.0-1.mga9
+ Revision: 1698791
- new version: 1.3.0
- remove merged upstream patches

* Wed Dec 16 2020 umeabot <umeabot> 1.2.0-2.mga8
+ Revision: 1658338
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 1.2.0-1.mga8
+ Revision: 1605894
- new version: 1.2.0
- switch to cmake build system

* Sat Feb 15 2020 umeabot <umeabot> 0.9.21-6.mga8
+ Revision: 1524561
- Mageia 8 Mass Rebuild

* Sat Mar 30 2019 umeabot <umeabot> 0.9.21-5.mga7
+ Revision: 1381624
- Qt5 Rebuild

* Sat Jan 12 2019 tv <tv> 0.9.21-4.mga7
+ Revision: 1355771
- rebuild for new capstone

* Sun Sep 23 2018 umeabot <umeabot> 0.9.21-3.mga7
+ Revision: 1297566
- Mageia 7 Mass Rebuild

* Sat Mar 31 2018 daviddavid <daviddavid> 0.9.21-2.mga7
+ Revision: 1213940
- package the upstream manpage

* Sat Mar 31 2018 daviddavid <daviddavid> 0.9.21-1.mga7
+ Revision: 1213912
- new version: 0.9.21
- port to Qt5

* Mon Jul 11 2016 pterjan <pterjan> 0.9.18-9.mga6
+ Revision: 1041175
- Restrict to supported arches

* Fri Feb 05 2016 umeabot <umeabot> 0.9.18-8.mga6
+ Revision: 938696
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.9.18-7.mga5
+ Revision: 747338
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.18-6.mga5
+ Revision: 678955
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.9.18-5.mga4
+ Revision: 529391
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 0.9.18-4.mga4
+ Revision: 451766
- rebuild for new boost

* Fri Jan 11 2013 umeabot <umeabot> 0.9.18-3.mga3
+ Revision: 349489
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Aug 25 2012 matteo <matteo> 0.9.18-2.mga3
+ Revision: 283947
- fixed install root
- spec file reviewed

* Mon Feb 06 2012 matteo <matteo> 0.9.18-1.mga2
+ Revision: 205392
- version upgrade

* Thu Jul 14 2011 matteo <matteo> 0.9.17-1.mga2
+ Revision: 124137
- edb-debugger.spec: added postun section
- edb-debugger.spec: fixed plugins path
- imported package edb-debugger


* Thu Jul 07 2011 Matteo Pasotti <pasotti.matteo@gmail.com> %%{version}-1
- create spec 

